Efficiently count the number of unique values in a set of vectors
Source:R/distinct.R
n_distinct.RdThis is a faster and more concise equivalent of length(unique(x))

R/distinct.R
n_distinct.RdThis is a faster and more concise equivalent of length(unique(x))